@@ -1,5 +1,5 @@
 startItems<-function (itemBank, model = NULL, fixItems = NULL, seed = NULL, 
-    nrItems = 1, theta = 0, D = 1, randomesque = 1, startSelect = "MFI", 
+    nrItems = 1, theta = 0, D = 1, randomesque = 1, random.seed=NULL, startSelect = "MFI", 
     nAvailable = NULL) 
 {
     if (!is.null(nAvailable)) {
@@ -37,8 +37,8 @@ startItems<-function (itemBank, model = NULL, fixItems = NULL, seed = NULL,
                 set.seed(NULL)
             }
             else {
-                  thStart <- theta
-                  if (startSelect != "bOpt" & startSelect != "thOpt" & 
+                thStart <- theta
+                if (startSelect != "bOpt" & startSelect != "thOpt" & 
                   startSelect != "MFI" & startSelect != "progressive" & 
                   startSelect != "proportional") 
                   stop("'startSelect' must be either 'bOpt', 'thOpt', 'progressive', 'proportional' or 'MFI'", 
@@ -50,14 +50,19 @@ startItems<-function (itemBank, model = NULL, fixItems = NULL, seed = NULL,
                   items = NULL
                   nr.items <- nrow(itemBank)
                   selected <- rep(0, nr.items)
+if (!is.null(random.seed)) set.seed(random.seed)
                   for (i in 1:length(thStart)) {
-                    item.dist <- abs(thStart[i] - itemBank[,2])
+                    item.dist <- abs(thStart[i] - itemBank[, 
+                      2])
                     if (!is.null(nAvailable)) 
                       pos.adm <- (1 - selected) * nAvailable
                     else pos.adm <- 1 - selected
-                    ra<-rank(abs(item.dist - min(item.dist[pos.adm == 1])))
-                    prov<-which(ra<=randomesque)[pos.adm[ra<=randomesque] == 1]
-                    items[i] <- ifelse(length(prov) == 1, prov, sample(prov, 1))
+                    ra <- rank(abs(item.dist - min(item.dist[pos.adm == 
+                      1])))
+                    prov <- which(ra <= randomesque)[pos.adm[ra <= 
+                      randomesque] == 1]
+                    items[i] <- ifelse(length(prov) == 1, prov, 
+                      sample(prov, 1))
                     selected[items[i]] <- 1
                   }
                 }
@@ -73,14 +78,18 @@ startItems<-function (itemBank, model = NULL, fixItems = NULL, seed = NULL,
                   thMax <- itemBank[, 2] + log((xstar - itemBank[, 
                     3])/(itemBank[, 4] - xstar))/(D * itemBank[, 
                     1])
-                    for (i in 1:length(thStart)) {
+if (!is.null(random.seed)) set.seed(random.seed)
+                  for (i in 1:length(thStart)) {
                     item.dist <- abs(thMax - thStart[i])
                     if (!is.null(nAvailable)) 
                       pos.adm <- (1 - selected) * nAvailable
                     else pos.adm <- 1 - selected
-                    ra<-rank(abs(item.dist - min(item.dist[pos.adm == 1])))
-                    prov<-which(ra<=randomesque)[pos.adm[ra<=randomesque] == 1]
-                    items[i] <- ifelse(length(prov) == 1, prov, sample(prov, 1))
+                    ra <- rank(abs(item.dist - min(item.dist[pos.adm == 
+                      1])))
+                    prov <- which(ra <= randomesque)[pos.adm[ra <= 
+                      randomesque] == 1]
+                    items[i] <- ifelse(length(prov) == 1, prov, 
+                      sample(prov, 1))
                     selected[items[i]] <- 1
                   }
                 }
@@ -88,15 +97,19 @@ startItems<-function (itemBank, model = NULL, fixItems = NULL, seed = NULL,
                   items = NULL
                   nr.items <- nrow(itemBank)
                   selected <- rep(0, nr.items)
+if (!is.null(random.seed)) set.seed(random.seed)
                   for (i in 1:length(thStart)) {
                     item.info <- Ii(thStart[i], itemBank, model = model, 
                       D = D)$Ii
                     if (!is.null(nAvailable)) 
                       pos.adm <- (1 - selected) * nAvailable
                     else pos.adm <- 1 - selected
-                    ra<-rank(abs(item.info-max(item.info[pos.adm == 1])))
-                    prov<-which(ra<=randomesque)[pos.adm[ra<=randomesque] == 1]
-                    items[i] <- ifelse(length(prov) == 1, prov, sample(prov, 1))
+                    ra <- rank(abs(item.info - max(item.info[pos.adm == 
+                      1])))
+                    prov <- which(ra <= randomesque)[pos.adm[ra <= 
+                      randomesque] == 1]
+                    items[i] <- ifelse(length(prov) == 1, prov, 
+                      sample(prov, 1))
                     selected[items[i]] <- 1
                   }
                 }
@@ -108,5 +121,6 @@ startItems<-function (itemBank, model = NULL, fixItems = NULL, seed = NULL,
         else res <- list(items = NULL, par = NULL, thStart = NULL, 
             startSelect = NULL)
     }
+set.seed(NULL)
     return(res)
 }
